# Seminar Datenanalyse, Institut für Publizistik, JGU Mainz
# 2024-06-17

library(report)
library(tidyverse)
theme_set(theme_minimal())
vb <- readxl::read_excel("data/victim_blaming.xlsx")

## Gruppenmittelwerte

vb |>
  group_by(stimulus_rec) |>
  summarise(
    v_11_mean = mean(v_11, na.rm = TRUE),
    v_11_sd = sd(v_11, na.rm = TRUE),
    n = n()
  )

## Varianzanalyse

results_anova <- aov(v_11 ~ stimulus_rec, data = vb)
results_anova

results_anova |>
  report_table()

## Post-Hoc Tests

results_anova |>
  TukeyHSD()

## Was ist eine Alphafehler-Korrektur und welche weiteren Post-Hoc-Tests gibt es?

pairwise.t.test(vb$v_5f, vb$stimulus_rec, p.adj = "bonferroni")

## Visualisierung

vb |>
  ggplot(aes(x = stimulus_rec, y = v_11)) +
  geom_boxplot() +
  labs(x = "Versuchsbedingung", y = "Mitleid")

vb |>
  ggplot(aes(x = stimulus_rec, y = v_11)) +
  stat_summary(fun.data = mean_cl_boot, geom = "pointrange") +
  labs(x = "Versuchsbedingung", y = "Mitleid (Mittelwert und 95% CI)") +
  coord_cartesian(ylim = c(3.5, 4.5))

 

