# Seminar Datenanalyse, Institut für Publizistik, JGU Mainz
# 2024-06-17

library(tidyverse)
tg <- read_tsv("data/telegram.tsv")

## Fälle auswählen

tg_querdenker <- tg |>
  filter(ideologie == "Querdenken") # Achtung, zwei Gleichheitszeichen!

## Wann ein und wann zwei `=`?

dim(tg)
dim(tg_querdenker)

tg_querdenker |>
  count(ideologie)

tg_rechte_quer_offline <- tg |>
  filter(ideologie == "Rechte" | ideologie == "Querdenken") |>
  filter(ziel_1 >= 6)
dim(tg_rechte_quer_offline)

## Variablen auswählen

tg_ideologie <- tg |>
  select(ideologie, monat)
tg_ideologie

tg_no_ideology <- tg |>
  select(-ideologie)
dim(tg_no_ideology)

## Selection helpers

## Daten sortieren

tg_ideologie |>
  arrange(desc(monat))

## Fehlende Werte definieren

kein_na <- c(1, -9)
mit_na <- c(1, NA)
sum(kein_na)

sum(mit_na)

sum(mit_na, na.rm = TRUE)

tg <- tg |>
  mutate(art_1 = if_else(art_1 == -9, NA, art_1))

## tiere |>
##   mutate(art = if_else(laute == "bellt", "Hund", "Kein Hund"))

tg <- tg |>
  mutate(
    art_1 = if_else(art_1 == -9, NA, art_1),
    art_2 = if_else(art_2 == -9, NA, art_2),
    art_3 = if_else(art_3 == -9, NA, art_3)
  )

tg <- tg |>
  mutate(
    art_1 = if_else(art_1 < 0, NA, art_1),
    art_2 = if_else(art_2 < 0, NA, art_2),
    art_3 = if_else(art_3 < 0, NA, art_3)
  )

## Arbeiten mit `mutate()`, `across()` und `selection helpers` 

## Variablen erstellen

tibble(gewicht = c(1000, 12000, 1250, 2500)) |>
  mutate(gewicht_in_kg = gewicht / 1000)

tibble(gewicht = c(1000, 12000, 1250, 2500)) |>
  mutate(
    gewicht_in_kg = gewicht / 1000,
    gewicht_in_lbs = gewicht / 453.6 # Gewicht in amerik. Pfund
  )

## Variablen recodieren

tg <- tg |>
  mutate(art_1rec = if_else(art_1 == 1 | art_1 == 2, "Handlungsaufforderung", "keine Handlungsaufforderung"))

tg <- tg |>
  mutate(art_1rec = if_else(art_1 <= 2, "Handlungsaufforderung", "keine Handlungsaufforderung"))

tg <- tg |>
  mutate(appell_ges = if_else(art_1 <= 2 | art_2 <= 2 | art_3 <= 2, "mindestens eine Handlungsaufforderung", "keine Handlungsaufforderung"))

