# Seminar Datenanalyse, Institut für Publizistik, JGU Mainz
# 2024-06-17

library(tidyverse)
theme_set(theme_minimal())
vb <- readxl::read_excel("data/victim_blaming.xlsx")
soziodemographie <- read_tsv("data/soziodemographie.tsv")

## ggplot(data = df, aes(x = alter, y = einkommen)) +
##   geom_point() +
##   labs(x = "Alter", y = "Einkommen (in Euro/Monat)")

## Balkendiagramm

soziodemographie

soziodemographie |>
  ggplot(aes(x = name, y = alter)) +
  labs(x = "Person", y = "Alter")

soziodemographie |>
  ggplot(aes(x = name, y = alter)) +
  labs(x = "Person", y = "Alter") +
  geom_col()

soziodemographie |>
  ggplot(aes(x = name, y = alter)) +
  labs(x = "Person", y = "Alter") +
  geom_point(size = 5)

soziodemographie |>
  ggplot(aes(x = name, y = alter)) +
  labs(x = "Person", y = "Alter") +
  geom_col() +
  geom_point(size = 5)

soziodemographie |>
  ggplot(aes(x = name, y = alter, fill = ist_verheiratet)) +
  geom_col() +
  labs(x = "Person", y = "Alter", fill = "Beziehungsstatus")

soziodemographie |>
  mutate(ist_verheiratet = if_else(ist_verheiratet == TRUE, "verheiratet", "nicht verheiratet")) |>
  ggplot(aes(x = reorder(name, alter, decreasing = TRUE), y = alter, fill = ist_verheiratet)) +
  geom_col() +
  labs(x = "Person", y = "Alter", fill = "Beziehungsstatus")

## Wertebereiche der Koordinatenachsen anpassen

freq_stimulus <- vb |>
  count(stimulus_rec)

freq_stimulus

freq_stimulus |>
  ggplot(aes(x = stimulus_rec, y = n)) +
  geom_col() +
  labs(x = "Versuchsbedingung", y = "Fallzahl n")

## `geom_col()` und `geom_bar()`

## Histogramme

vb |>
  ggplot(aes(x = vb_index)) +
  geom_histogram() +
  labs(x = "Victim Blaming Index")

## Grafische Darstellung von mehreren Variablen mit `facet_wrap()` und `gather()`

vb |>
  select(v_14a:v_14e, vb_index) |>
  gather(variablen, wert) |> # gather is mittlerweile ersetzt worden durch pivot_longer(), ist aber noch häufig in Tutorials und Online-Quellen zu finden.
  ggplot(aes(x = wert)) +
  geom_histogram() +
  facet_wrap(~variablen) +
  labs(x = "Ausprägung", y = "Häufigkeit")

vb |>
  select(v_14a:v_14e, vb_index) |>
  gather(variablen, wert) |> # gather is mittlerweile ersetzt worden durch pivot_longer(), ist aber noch häufig in Tutorials und Online-Quellen zu finden.
  mutate(variablen = factor(variablen, labels = c("Item 1", "Item 2", "Item 3", "Item 4", "Item 5", "Index"))) |> # Unter labels können wir die Namen der Variablen eintragen
  ggplot(aes(x = wert)) +
  geom_histogram() +
  facet_wrap(~variablen) +
  labs(x = "Ausprägung", y = "Häufigkeit")

## Streudiagramme

vb |>
  ggplot(aes(x = v_5j, y = v_5k)) +
  geom_point() +
  labs(x = "Attraktivität", y = "Sympathie")

vb |>
  ggplot(aes(x = v_5j, y = v_5k)) +
  geom_jitter(height = 0.5, width = 0.5) +
  labs(x = "Attraktivität", y = "Sympathie")

vb |>
  ggplot(aes(x = v_5j, y = v_5k, color = v_2)) +
  geom_jitter(height = 0.5, width = 0.5) +
  labs(x = "Attraktivität", y = "Sympathie", color = "Geschlecht")

## Liniendiagramme

avg_vb <- vb |>
  group_by(v_1) |>
  summarise(mean_vb = mean(vb_index))
avg_vb

avg_vb |>
  ggplot(aes(x = v_1, y = mean_vb)) +
  geom_line() +
  labs(x = "Alter", y = "VB Index (Durchschnitt)")

avg_vb |>
  ggplot(aes(x = v_1, y = mean_vb)) +
  geom_line() +
  geom_point() +
  labs(x = "Alter", y = "VB Index (Durchschnitt)")

