# Seminar Datenanalyse, Institut für Publizistik, JGU Mainz
# 2024-06-17

library(tidyverse)
vb <- readxl::read_excel("data/victim_blaming.xlsx")

## Daten zusammenfassen

## Maße der zentralen Tendenz

vb |>
  summarise(
    mean_alter = mean(v_1),
    median_alter = median(v_1),
    min_alter = min(v_1),
    max_alter = max(v_1)
  )

## Fehlende Werte oder "Warum bekomme ich immer NA zurück?"

vb |>
  summarise(min_strafe = min(v_9a)) # klappt nicht wegen NA

vb |>
  summarise(min_strafe = min(v_9a, na.rm = TRUE)) # klappt besser

## Dispersionsmaße

vb |>
  summarise(
    sd_alter = sd(v_1, na.rm = TRUE),
    range_alter = max(v_1, na.rm = TRUE) - min(v_1, na.rm = TRUE),
  )

vb |>
  summarise(
    mean_alter = mean(v_1, na.rm = TRUE),
    sd_alter = sd(v_1, na.rm = TRUE),
    mean_empathie = mean(v_13, na.rm = TRUE),
    sd_empathie = sd(v_13, na.rm = TRUE)
  )

## tabellarische Darstellung von mehr als zwei Variablen 

## Gruppenvergleiche

vb |>
  summarise(
    mean_alter = mean(v_1, na.rm = TRUE),
    sd_alter = sd(v_1, na.rm = TRUE)
  )

vb |>
  group_by(stimulus_rec) |> # nur dies haben wir eingefügt
  summarise(
    mean_alter = mean(v_1, na.rm = TRUE),
    sd_alter = sd(v_1, na.rm = TRUE)
  )

## `group_by()` in Verbindung mit der Erstellung von Objekten

## Häufigkeiten

vb |>
  summarise(n_cases = n())

vb |>
  group_by(stimulus_rec) |>
  summarise(n_cases = n())

vb |>
  count(stimulus_rec)

vb |>
  count(stimulus_rec) |>
  mutate(
    rel_freq = n / sum(n), # relative Häufigkeit
    percent = rel_freq * 100 # Prozentwerte
  )

## Dummy-Variablen auswerten

freq_stimulus <- vb |>
  count(stimulus_rec) |>
  mutate(percent = n / sum(n) * 100) |> # Prozentwerte
  arrange(desc(n)) # absteigende Häufigkeiten

freq_stimulus

