# Seminar Datenanalyse, Institut für Publizistik, JGU Mainz
# 2024-06-17

library(report)
library(tidyverse)
theme_set(theme_minimal())
tg <- read_tsv("data/telegram.tsv")

## Einfache Häufigkeiten

tg |>
  count(ideologie) |>
  mutate(percent = n / sum(n) * 100) |> # Prozentwerte
  arrange(desc(n))

tg |>
  count(ziel_1) |>
  mutate(percent = n / sum(n) * 100) |> # Prozentwerte
  arrange(desc(n)) |>
  print(n = 20)

## Variablen recodieren

tg <- tg |>
  mutate(ziel_1_recodiert = case_when(
    ziel_1 == 1 ~ 1,
    ziel_1 == 2 ~ 1,
    ziel_1 == 3 ~ 1,
    ziel_1 == 4 ~ 1,
    ziel_1 == 5 ~ 1,
    ziel_1 == 6 ~ 2,
    ziel_1 == 7 ~ 2,
    ziel_1 == 8 ~ 3,
    TRUE ~ NA
  ))

tg <- tg |>
  mutate(ziel_1_recodiert = case_when(
    ziel_1 == 1 ~ "Online-Handlungen",
    ziel_1 == 2 ~ "Online-Handlungen",
    ziel_1 == 3 ~ "Online-Handlungen",
    ziel_1 == 4 ~ "Online-Handlungen",
    ziel_1 == 5 ~ "Online-Handlungen",
    ziel_1 == 6 ~ "Offline-Handlungen",
    ziel_1 == 7 ~ "Offline-Handlungen",
    ziel_1 == 8 ~ "Gewaltaufrufe",
    TRUE ~ NA
  ))

## Arbeiten mit dem %in%-Operator

## Kreuztabelle

tg |>
  count(ideologie, ziel_1_recodiert)

tg |>
  select(ziel_1_recodiert, ideologie) |>
  table()

ideo_table <- tg |>
  select(ziel_1_recodiert, ideologie) |>
  table()

ideo_table |>
  prop.table(margin = 2) |>
  round(digits = 2)

ideo_final <- ideo_table |>
  addmargins(margin = 2) |>
  prop.table(margin = 2)

round(ideo_final * 100, digits = 0)

## Chi-Quadrat-Test

ideo_table |>
  chisq.test()

ideo_table |>
  chisq.test() |>
  report_table()

## Visualisierung

ideo_tab_long <- tg |>
  filter(!is.na(ziel_1_recodiert)) |>
  count(ideologie, ziel_1_recodiert) |>
  group_by(ideologie) |>
  mutate(percent = n / sum(n) * 100)

ideo_tab_long

ideo_tab_long |>
  ggplot(aes(x = ideologie, y = percent, fill = ziel_1_recodiert)) +
  geom_col() +
  labs(x = "Art des Telegram-Kanals", y = "Häufigkeit (%)", fill = "Art der Aufrufe")

ideo_tab_long |>
  ggplot(aes(x = ideologie, y = percent, fill = ziel_1_recodiert)) +
  geom_col(position = position_dodge()) +
  labs(x = "Art des Telegram-Kanals", y = "Häufigkeit (%)", fill = "Art der Aufrufe")

